@@ -115,6 +115,7 @@ CATEGORY_MAP = {
     "kabeuchi"       : "かべうち",
     "kaliscan"       : "KaliScan",
     "mangafire"      : "MangaFire",
+    "mangafreak"     : "MangaFreak",
     "mangareader"    : "MangaReader",
     "mangataro"      : "MangaTaro",
     "s3ndpics"       : "S3ND",
@@ -128,6 +129,7 @@ CATEGORY_MAP = {
     "mangafox"       : "Manga Fox",
     "mangahere"      : "Manga Here",
     "mangakakalot"   : "MangaKakalot",
+    "mangatown"      : "MangaTown",
     "manganato"      : "MangaNato",
     "mangapark"      : "MangaPark",
     "mangaread"      : "MangaRead",
@@ -185,6 +187,7 @@ CATEGORY_MAP = {
     "slickpic"       : "SlickPic",
     "slideshare"     : "SlideShare",
     "smugmug"        : "SmugMug",
+    "socialmediagirlsforum": "Social Media Girls Forums",
     "speakerdeck"    : "Speaker Deck",
     "steamgriddb"    : "SteamGridDB",
     "subscribestar"  : "SubscribeStar",
@@ -198,6 +201,7 @@ CATEGORY_MAP = {
     "thefap"         : "TheFap",
     "thehentaiworld" : "The Hentai World",
     "tiktok"         : "TikTok",
+    "titsintops"     : "Tits In Tops Forum",
     "tmohentai"      : "TMOHentai",
     "tumblrgallery"  : "TumblrGallery",
     "turboimagehost" : "TurboImageHost.com",
@@ -237,6 +241,7 @@ SUBCATEGORY_MAP = {
     "issue"  : "Comic Issues",
     "manga"  : "Manga",
     "media"  : "Media Files",
+    "people" : "People",
     "popular": "Popular Images",
     "recent" : "Recent Images",
     "saved"  : "Saved Posts",
